@@ -2,7 +2,7 @@
   
   if (requireNamespace("knitr", quietly = TRUE)) {
     knit_engines <- get("knit_engines", envir = asNamespace("knitr"))
-    knit_engines$set(nomnoml = knit_nomnoml)
+    knit_engines$set(nomnoml = function(...) knit_nomnoml(...))
   }
 
 }
\ No newline at end of file
